@@ -2,11 +2,6 @@ import os
 
 from django.utils.translation import ugettext_lazy as _
 
-try:
-    from localsettings import *
-except ImportError:
-    pass
-
 # Django settings for wafer project.
 
 ADMINS = (
@@ -121,7 +116,7 @@ TEMPLATES = [
 ]
 
 
-MIDDLEWARE_CLASSES = (
+MIDDLEWARE = (
     'django.middleware.common.CommonMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
@@ -147,12 +142,11 @@ INSTALLED_APPS = (
     'django.contrib.staticfiles',
     'django.contrib.redirects',
     'reversion',
-    'django_medusa',
+    'bakery',
     'crispy_forms',
     'django_nose',
-    'markitup',
     'rest_framework',
-    'easy_select2',
+    'django_select2',
     'wafer',
     'wafer.kv',
     'wafer.registration',
@@ -164,6 +158,7 @@ INSTALLED_APPS = (
     'wafer.tickets',
     'wafer.compare',
     # Django isn't finding the overridden templates
+    'markitup',
     'registration',
     'django.contrib.admin',
 )
@@ -241,28 +236,23 @@ WAFER_MENUS = ()
 
 WAFER_DYNAMIC_MENUS = (
     'wafer.pages.models.page_menus',
+    'wafer.sponsors.models.sponsor_menu',
 )
 
 # Enabled SSO mechanims:
 WAFER_SSO = (
     # 'github',
-    # 'debian',
+    # 'gitlab',
 )
 
 # Log in with GitHub:
 # WAFER_GITHUB_CLIENT_ID = 'register on github'
 # WAFER_GITHUB_CLIENT_SECRET = 'to get these secrets'
 
-# Log in with Debian SSO:
-# Requires some Apache config:
-# SSLCACertificateFile /srv/sso.debian.org/etc/debsso.crt
-# SSLCARevocationCheck chain
-# SSLCARevocationFile /srv/sso.debian.org/etc/debsso.crl
-# <Location /accounts/debian-login/>
-#     SSLOptions +StdEnvVars
-#     SSLVerifyClient optional
-# </Location>
-# WAFER_DEBIAN_NM_API_KEY = 'obtain one from https://nm.debian.org/apikeys/'
+# Log in with GitLab:
+# WAFER_GITLAB_HOSTNAME = 'gitlab.com'
+# WAFER_GITLAB_CLIENT_ID = 'register on github'
+# WAFER_GITLAB_CLIENT_SECRET = 'to get these secrets'
 
 # Set this to true to disable the login button on the navigation toolbar
 WAFER_HIDE_LOGIN = False
@@ -277,14 +267,21 @@ WAFER_TALK_FORM = 'wafer.talks.forms.TalkForm'
 # Ask speakers for video release, and an email address of a reviewer
 WAFER_VIDEO = True
 WAFER_VIDEO_REVIEWER = True
+WAFER_VIDEO_LICENSE = 'CC BY-SA 4.0'
+WAFER_VIDEO_LICENSE_URL = 'https://creativecommons.org/licenses/by-sa/4.0/'
+
+# Range of scores for talk reviews (inclusive)
+WAFER_TALK_REVIEW_SCORES = (-2, 2)
 
 # Set this to False to disable registration
 WAFER_REGISTRATION_OPEN = True
-# Can be 'ticket' for Quicket tickets or 'form' for a classic form
-WAFER_REGISTRATION_MODE = 'ticket'
 
-# For REGISTRATION_MODE == 'form', the form to present
-WAFER_REGISTRATION_FORM = 'wafer.users.forms.ExampleRegistrationForm'
+# WAFER_REGISTRATION_MODE can be 'ticket' for Quicket tickets, or 'custom' if
+# you implement your own registration system. If 'custom', then you *must*
+# define a URL named 'register' in your application so we can link to it.
+WAFER_REGISTRATION_MODE = 'ticket'
+# WAFER_USER_IS_REGISTERED should return a boolean, when passed a Django user.
+WAFER_USER_IS_REGISTERED = 'wafer.tickets.models.user_is_registered'
 
 # Allow registered and anonymous users to see registered users
 WAFER_PUBLIC_ATTENDEE_LIST = True
@@ -292,12 +289,33 @@ WAFER_PUBLIC_ATTENDEE_LIST = True
 # Ticket registration with Quicket
 # WAFER_TICKET_SECRET = "i'm a shared secret"
 
-# django_medusa -- disk-based renderer
-MEDUSA_RENDERER_CLASS = "wafer.management.static.WaferDiskStaticSiteRenderer"
-MEDUSA_DEPLOY_DIR = os.path.join(project_root, 'static_mirror')
+# django-bakery -- disk-based renderer
+BUILD_DIR = os.path.join(project_root, 'static_mirror')
+
 MARKITUP_FILTER = ('markdown.markdown', {'safe_mode': True})
+JQUERY_URL = None
+SELECT2_USE_BUNDLED_JQUERY = False
 
 REST_FRAMEWORK = {
     'DEFAULT_PERMISSION_CLASSES': ('rest_framework.permissions.IsAdminUser',),
+    'DEFAULT_PAGINATION_CLASS': 'rest_framework.pagination.LimitOffsetPagination',
     'PAGE_SIZE': 50
 }
+
+BAKERY_VIEWS = (
+    'wafer.pages.views.ShowPage',
+    'wafer.schedule.views.VenueView',
+    'wafer.schedule.views.ScheduleView',
+    'wafer.schedule.views.ScheduleXmlView',
+    'wafer.schedule.views.ICalView',
+    'wafer.sponsors.views.ShowSponsors',
+    'wafer.sponsors.views.ShowPackages',
+    'wafer.sponsors.views.SponsorView',
+    'wafer.talks.views.TalkView',
+    'wafer.talks.views.Speakers',
+    'wafer.talks.views.TracksView',
+    'wafer.talks.views.TalkTypesView',
+    'wafer.talks.views.UsersTalks',
+    'wafer.users.views.UsersView',
+    'wafer.users.views.ProfileView',
+)
