@@ -8,15 +8,20 @@ register = template.Library()
 @register.inclusion_tag('wafer.sponsors/sponsors_block.html')
 def sponsors():
     return {
-        'sponsors': Sponsor.objects.all().order_by('packages'),
+        'sponsors': Sponsor.objects.all().order_by('packages', 'order', 'id'),
         'packages': SponsorshipPackage.objects.all().prefetch_related('files'),
     }
 
 
-# We use assignment_tag for compatibility with Django 1.8
-# Once we drop 1.8 support, we should change this to
-# simple_tag
-@register.assignment_tag()
+@register.inclusion_tag('wafer.sponsors/sponsors_footer.html')
+def sponsors_footer():
+    return {
+        'sponsors': Sponsor.objects.all().order_by('packages', 'order', 'id'),
+        'packages': SponsorshipPackage.objects.all().prefetch_related('files'),
+    }
+
+
+@register.simple_tag()
 def sponsor_image_url(sponsor, name):
     """Returns the corresponding url from the sponsors images"""
     if sponsor.files.filter(name=name).exists():
@@ -24,3 +29,11 @@ def sponsor_image_url(sponsor, name):
         # returning the first one.
         return sponsor.files.filter(name=name).first().item.url
     return ''
+
+
+@register.simple_tag()
+def sponsor_tagged_image(sponsor, tag):
+    """returns the corresponding url from the tagged image list."""
+    if sponsor.files.filter(tag_name=tag).exists():
+        return sponsor.files.filter(tag_name=tag).first().tagged_file.item.url
+    return ''
