@@ -4,8 +4,8 @@ import mock
 
 from django.contrib.auth import get_user_model
 from django.contrib.auth.models import Permission
-from django.core.urlresolvers import reverse
 from django.test import Client, TestCase
+from django.urls import reverse
 
 from wafer.tests.api_utils import SortedResultsClient
 from wafer.talks.models import (
@@ -97,8 +97,7 @@ class TalkViewTests(TestCase):
     def check_talk_view(self, talk, status_code, auth=None):
         if auth is not None:
             self.client.login(**auth)
-        response = self.client.get(
-            reverse('wafer_talk', kwargs={'pk': talk.pk}))
+        response = self.client.get(talk.get_absolute_url())
         self.assertEqual(response.status_code, status_code)
 
     def test_view_accepted_not_logged_in(self):
@@ -180,6 +179,17 @@ class TalkViewTests(TestCase):
             'username': 'reviewer', 'password': 'reviewer_password',
         })
 
+    def test_view_canonicalizes_url(self):
+        response = self.client.get(
+            reverse('wafer_talk', kwargs={'pk': self.talk_a.pk}))
+        self.assertEqual(response.status_code, 302)
+
+    def test_view_canonicalizes_url_correctly(self):
+        response = self.client.get(
+            reverse('wafer_talk', kwargs={'pk': self.talk_a.pk}),
+            follow=True)
+        self.assertEqual(response.status_code, 200)
+
 
 class TalkNoteViewTests(TestCase):
     def setUp(self):
@@ -191,8 +201,7 @@ class TalkNoteViewTests(TestCase):
                         auth=None):
         if auth is not None:
             self.client.login(**auth)
-        response = self.client.get(
-            reverse('wafer_talk', kwargs={'pk': talk.pk}))
+        response = self.client.get(talk.get_absolute_url())
         if notes_visible:
             self.assertTrue('Some notes for talk' in response.rendered_content)
         else:
@@ -375,18 +384,25 @@ class SpeakerTests(TestCase):
             reverse('wafer_talks_speakers'))
         self.assertEqual(response.status_code, 200)
         self.assertContains(response, "\n".join([
-            '<div class="container">',
-            '<div class="row">',
+            '<section class="wafer wafer-speakers">',
+            '<h1>Speakers</h1>'
+            '<div class="container">'
+            '  <div class="row">',
             '    <div class="col-md-3">',
-            '      <a href="/users/%s/">' % username,
-            '        <img class="thumbnail mx-auto" src="%s">' % img,
-            '      </a>',
-            '      <a href="/users/%s/">' % username,
-            '        <h3 class="text-center">author_a</h3>',
-            '      </a>',
+            '      <div class="wafer-speakers-logo">',
+            '        <a href="/users/%s/">' % username,
+            '          <img class="thumbnail mx-auto" src="%s">' % img,
+            '        </a>',
+            '      </div>',
+            '      <div class="wafer-speakers-name">',
+            '        <a href="/users/%s/">' % username,
+            '          author_a',
+            '        </a>',
+            '      </div>',
             '    </div>',
+            '  </div>',
             '</div>',
-            '</div>',
+            '</section>',
         ]), html=True)
 
     def check_n_speakers(self, n, expected_rows):
@@ -420,6 +436,49 @@ class SpeakerTests(TestCase):
         self.check_n_speakers(7, [(0, 4), (4, 7)])
 
 
+class TalkSlugUrlTests(TestCase):
+    """Check that we can lookup a talk via correct and incorrect slugs"""
+    def setUp(self):
+        self.talk_a = create_talk('Test Talk 1', ACCEPTED, "author_a")
+        # Unicode talk will generate empty slug - this should not crash
+        self.talk_b = create_talk(u'\xa9\xa3', ACCEPTED, "author_b")
+        self.client = Client()
+
+    def test_slug_generation(self):
+        self.assertEqual(self.talk_a.slug, 'test-talk-1')
+        self.assertEqual(self.talk_b.slug, '')
+
+    def test_non_unicode_slug_lookups(self):
+        response = self.client.get('/talks/%d-test-talk-1/' % self.talk_a.pk)
+        self.assertEqual(response.status_code, 200)
+        self.assertContains(response, '%s' % self.talk_a.title)
+
+        response = self.client.get('/talks/%d-bogus-slug/' % self.talk_a.pk)
+        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.url, '/talks/%d-test-talk-1/' % self.talk_a.pk)
+
+        response = self.client.get('/talks/%d-/' % self.talk_a.pk)
+        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.url, '/talks/%d-test-talk-1/' % self.talk_a.pk)
+
+        response = self.client.get('/talks/%d/' % self.talk_a.pk)
+        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.url, '/talks/%d-test-talk-1/' % self.talk_a.pk)
+
+    def test_unicode_slug_lookups(self):
+        response = self.client.get('/talks/%d-/' % self.talk_b.pk)
+        self.assertEqual(response.status_code, 200)
+        self.assertContains(response, '%s' % self.talk_b.title)
+
+        response = self.client.get('/talks/%d-bogus-slug/' % self.talk_b.pk)
+        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.url, '/talks/%d-/' % self.talk_b.pk)
+
+        response = self.client.get('/talks/%d/' % self.talk_b.pk)
+        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.url, '/talks/%d-/' % self.talk_b.pk)
+
+
 class TalkViewSetPermissionTests(TestCase):
 
     def setUp(self):
@@ -523,7 +582,7 @@ class TalkViewSetTests(TestCase):
             'corresponding_author': talk.corresponding_author.id,
             'authors': [talk.corresponding_author.id],
             'kv': [],
-            'urls': [mk_url(url) for url in talk.talkurl_set.all()]
+            'urls': [mk_url(url) for url in talk.urls.all()]
         }
 
     def test_list_talks(self):
@@ -673,7 +732,7 @@ class TalkUrlsViewSetTests(TestCase):
                 'description': u'slides',
                 'url': u'http://www.example.com/video',
             }, format="json")
-        [talk_url] = talk.talkurl_set.all()
+        [talk_url] = talk.urls.all()
         self.assertEqual(response.data, self.mk_result(talk_url))
         self.assertEqual(talk_url.url, u'http://www.example.com/video')
         self.assertEqual(talk_url.description, u'slides')
@@ -687,7 +746,7 @@ class TalkUrlsViewSetTests(TestCase):
                 'description': u'slides',
                 'url': u'http://www.example.com/video',
             }, format="json")
-        [talk_url] = talk.talkurl_set.all()
+        [talk_url] = talk.urls.all()
         self.assertEqual(response.data, self.mk_result(talk_url))
         self.assertEqual(talk_url.url, u'http://www.example.com/video')
         self.assertEqual(talk_url.description, u'slides')
@@ -700,7 +759,7 @@ class TalkUrlsViewSetTests(TestCase):
             '/talks/api/talks/%d/urls/%d/' % (talk.talk_id, url.id), data={
                 'url': 'http://new.example.com/',
             }, format="json")
-        [talk_url] = talk.talkurl_set.all()
+        [talk_url] = talk.urls.all()
         self.assertEqual(response.data, self.mk_result(talk_url))
         self.assertEqual(talk_url.url, u'http://new.example.com/')
         self.assertEqual(talk_url.description, u'video')
@@ -713,7 +772,7 @@ class TalkUrlsViewSetTests(TestCase):
             talk=talk, url="http://a.example.com/", description="video")
         response = self.client.delete(
             '/talks/api/talks/%d/urls/%d/' % (talk.talk_id, url_a.id))
-        [talk_url_b] = talk.talkurl_set.all()
+        [talk_url_b] = talk.urls.all()
         self.assertEqual(response.data, None)
         self.assertEqual(response.status_code, 204)
         self.assertEqual(talk_url_b, url_b)
