@@ -1,25 +1,30 @@
-from django.core.exceptions import PermissionDenied, ValidationError
-from django.core.urlresolvers import reverse_lazy
-from django.http import HttpResponseRedirect
-from django.views.generic import DetailView
-from django.views.generic.edit import CreateView, UpdateView, DeleteView
-from django.views.generic.list import ListView
 from django.conf import settings
+from django.contrib.auth.mixins import (
+    LoginRequiredMixin, PermissionRequiredMixin)
+from django.contrib.auth.models import AnonymousUser
+from django.core.exceptions import PermissionDenied, ValidationError
 from django.db.models import Q
 from django.http import Http404
+from django.http import HttpResponseRedirect
+from django.urls import reverse_lazy
+from django.views.generic.edit import CreateView, UpdateView, DeleteView
 
-from reversion import revisions
+from bakery.views import BuildableDetailView, BuildableListView
 from rest_framework import viewsets
 from rest_framework.permissions import (
     DjangoModelPermissions, DjangoModelPermissionsOrAnonReadOnly,
     BasePermission)
 from rest_framework_extensions.mixins import NestedViewSetMixin
+from reversion import revisions
+from reversion.models import Version
 
-from wafer.utils import LoginRequiredMixin
-from wafer.talks.models import Talk, TalkType, TalkUrl, ACCEPTED, CANCELLED
-from wafer.talks.forms import get_talk_form_class
+from wafer.talks.models import (
+    Review, Talk, TalkType, TalkUrl, Track,
+    ACCEPTED, CANCELLED, SUBMITTED, UNDER_CONSIDERATION, WITHDRAWN)
+from wafer.talks.forms import ReviewForm, get_talk_form_class
 from wafer.talks.serializers import TalkSerializer, TalkUrlSerializer
 from wafer.users.models import UserProfile
+from wafer.utils import order_results_by, PaginatedBuildableListView
 
 
 class EditOwnTalksMixin(object):
@@ -33,34 +38,66 @@ class EditOwnTalksMixin(object):
             raise PermissionDenied
 
 
-class UsersTalks(ListView):
+class UsersTalks(PaginatedBuildableListView):
     template_name = 'wafer.talks/talks.html'
+    build_prefix = 'talks'
     paginate_by = 25
 
+    @order_results_by('talk_type', 'talk_id')
     def get_queryset(self):
         # self.request will be None when we come here via the static site
         # renderer
         if (self.request and Talk.can_view_all(self.request.user)):
             return Talk.objects.all()
-        return Talk.objects.filter( Q(status=ACCEPTED) |
-                                    Q(status=CANCELLED))
+        return Talk.objects.filter(Q(status=ACCEPTED) |
+                                   Q(status=CANCELLED))
 
 
-class TalkView(DetailView):
+class TalkView(BuildableDetailView):
     template_name = 'wafer.talks/talk.html'
     model = Talk
 
+    # Needed so django-bakery only renders public talks
+    def build_object(self, obj):
+        """Override django-bakery to skip talks that raise 403"""
+        try:
+            super(TalkView, self).build_object(obj)
+        except PermissionDenied:
+            # We cleanup the directory created
+            self.unbuild_object(obj)
+
+    def create_request(self, path):
+        request = super(TalkView, self).create_request(path)
+        request.user = AnonymousUser()
+        return request
+
     def get_object(self, *args, **kwargs):
         '''Only talk owners can see talks, unless they've been accepted'''
         object_ = super(TalkView, self).get_object(*args, **kwargs)
-        if object_.can_view(self.request.user):
-            return object_
-        else:
+        if not object_.can_view(self.request.user):
             raise PermissionDenied
+        return object_
+
+    def render_to_response(self, *args, **kwargs):
+        '''Canonicalize the URL if the slug changed'''
+        if self.request.path != self.object.get_absolute_url():
+            return HttpResponseRedirect(self.object.get_absolute_url())
+        return super(TalkView, self).render_to_response(*args, **kwargs)
 
     def get_context_data(self, **kwargs):
         context = super(TalkView, self).get_context_data(**kwargs)
-        context['can_edit'] = self.object.can_edit(self.request.user)
+        talk = self.object
+        user = self.request.user
+
+        context['can_edit'] = talk.can_edit(user)
+
+        can_review = talk.can_review(user)
+        context['can_review'] = can_review
+        if can_review:
+            review = talk.reviews.filter(reviewer=user).first()
+            context['review_form'] = ReviewForm(
+                instance=review, talk=talk, user=user)
+
         return context
 
 
@@ -81,8 +118,7 @@ class TalkCreate(LoginRequiredMixin, CreateView):
         can_submit = getattr(settings, 'WAFER_TALKS_OPEN', True)
         if can_submit and TalkType.objects.exists():
             # Check for all talk types being disabled
-            can_submit = TalkType.objects.filter(
-                disable_submission=False).count() > 0
+            can_submit = TalkType.objects.open_for_submission().count() > 0
         context['can_submit'] = can_submit
         return context
 
@@ -127,21 +163,74 @@ class TalkUpdate(EditOwnTalksMixin, UpdateView):
         return super(TalkUpdate, self).form_valid(form)
 
 
-class TalkDelete(EditOwnTalksMixin, DeleteView):
+class TalkWithdraw(EditOwnTalksMixin, DeleteView):
     model = Talk
-    template_name = 'wafer.talks/talk_delete.html'
+    template_name = 'wafer.talks/talk_withdraw.html'
     success_url = reverse_lazy('wafer_page')
 
     @revisions.create_revision()
+    def delete(self, request, *args, **kwargs):
+        """Override delete to only withdraw"""
+        talk = self.get_object()
+        talk.status = WITHDRAWN
+        talk.save()
+        revisions.set_user(self.request.user)
+        revisions.set_comment("Talk Withdrawn")
+        return HttpResponseRedirect(self.success_url)
+
+
+class TalkReview(PermissionRequiredMixin, CreateView):
+    model = Review
+    form_class = ReviewForm
+    permission_required = 'talks.add_review'
+    template_name = 'wafer.talks/review_talk.html'
+
+    def get_form_kwargs(self):
+        kwargs = super(TalkReview, self).get_form_kwargs()
+        kwargs['talk'] = Talk.objects.get(pk=self.kwargs['pk'])
+        kwargs['instance'] = self.get_object()
+        kwargs['user'] = self.request.user
+        return kwargs
+
+    def get_object(self):
+        try:
+            return Review.objects.get(
+                talk_id=self.kwargs['pk'], reviewer=self.request.user)
+        except Review.DoesNotExist:
+            return None
+
     def form_valid(self, form):
-        # We don't add any metadata, as the admin site
-        # doesn't show it for deleted talks.
-        return super(TalkDelete, self).form_valid(form)
+        existing = self.get_object()
+        with revisions.create_revision():
+            response = super(TalkReview, self).form_valid(form)
+            revisions.set_user(self.request.user)
+            if existing:
+                revisions.set_comment("Review Modified")
+            else:
+                revisions.set_comment("Review Created")
+
+        # Because Review.save() was called before any scores were added,
+        # the str() on the version would have had the previous total. Update.
+        review = self.get_object()
+        version = Version.objects.get_for_object(review).order_by('-pk').first()
+        version.object_repr = str(review)
+        version.save()
+
+        talk = review.talk
+        if talk.status == SUBMITTED:
+            talk.status = UNDER_CONSIDERATION
+            talk.save()
+
+        return response
+
+    def get_success_url(self):
+        return self.get_object().talk.get_absolute_url()
 
 
-class Speakers(ListView):
+class Speakers(BuildableListView):
     model = Talk
     template_name = 'wafer.talks/speakers.html'
+    build_path = 'talks/speakers/index.html'
 
     def _by_row(self, speakers, n):
         return [speakers[i:i + n] for i in range(0, len(speakers), n)]
@@ -155,6 +244,18 @@ class Speakers(ListView):
         return context
 
 
+class TracksView(BuildableListView):
+    model = Track
+    template_name = 'wafer.talks/talk_tracks.html'
+    build_path = 'talks/tracks/index.html'
+
+
+class TalkTypesView(BuildableListView):
+    model = TalkType
+    template_name = 'wafer.talks/talk_types.html'
+    build_path = 'talks/types/index.html'
+
+
 class TalksViewSet(viewsets.ModelViewSet, NestedViewSetMixin):
     """API endpoint that allows talks to be viewed or edited."""
     queryset = Talk.objects.none()  # Needed for the REST Permissions
@@ -162,6 +263,7 @@ class TalksViewSet(viewsets.ModelViewSet, NestedViewSetMixin):
     # XXX: Do we want to allow authors to edit talks via the API?
     permission_classes = (DjangoModelPermissionsOrAnonReadOnly, )
 
+    @order_results_by('talk_type', 'talk_id')
     def get_queryset(self):
         # We override the default implementation to only show accepted talks
         # to people who aren't part of the management group
@@ -191,7 +293,7 @@ class TalkExistsPermission(BasePermission):
 
 class TalkUrlsViewSet(viewsets.ModelViewSet, NestedViewSetMixin):
     """API endpoint that allows talks to be viewed or edited."""
-    queryset = TalkUrl.objects.all()
+    queryset = TalkUrl.objects.all().order_by('id')
     serializer_class = TalkUrlSerializer
     permission_classes = (DjangoModelPermissions, TalkExistsPermission)
 
